# Cover renderer
# 
# Coded by dre (c) 2014
# Support: board.dreambox-tools.info
# E-Mail: dre@dreambox-tools.info
#
# This renderer is open source but it is NOT free software.
#
# This renderer may only be distributed to and executed on hardware which
# is licensed by Dream Multimedia GmbH.
# In other words:
# It's NOT allowed to distribute any parts of this renderer or its source code in ANY way
# to hardware which is NOT licensed by Dream Multimedia GmbH.
# It's NOT allowed to execute this renderer and its source code or even parts of it in ANY way
# on hardware which is NOT licensed by Dream Multimedia GmbH.
#
# If you want to use or modify the code or parts of it,	 
# you have to keep MY license and inform me about the modifications by mail.

from Renderer import Renderer
from enigma import ePixmap, eEnv
from Tools.Directories import fileExists, SCOPE_SKIN_IMAGE, SCOPE_CURRENT_SKIN, resolveFilename
from Components.config import config
from os import listdir as os_listdir, path as os_path

class Cover(Renderer):
	searchPaths = (eEnv.resolve('${datadir}/enigma2/cover/'),
				'/media/cf/cover/',
				'/media/usb/cover/',
				'/media/sdcard/cover/',
				'/data/cover/',)	
	
	if os_path.ismount('/dreambox-data'):
		searchPaths = searchPaths + ("/dreambox-data/cover/",)			
	# add mounts to searchPaths (mounted at boot time only!)	
	blockList = ["hdd","cf","usb","sdcard"]
	dirList = os_listdir("/media")
	
	if fileExists("/proc/mounts"):
		mountsFile = open("/proc/mounts" ,"r")
		for line in mountsFile:
			entry = line.split()
			if entry[2] in ["nfs", "nfs4", "smbfs", "cifs"]:
				if entry[1].startswith("/media/"):
					blockList.append(entry[1][7:])
		mountsFile.close()	
		
	for dir in dirList:
		if dir in blockList:
			continue
		if os_path.ismount("/media/%s" %(dir)) or (os_path.islink("/media/%s" %(dir)) and os_path.ismount(os_path.realpath("/media/%s" %(dir)))):
			searchPaths = searchPaths + ("/media/%s" %(dir) + "/cover/",)	
	
	def __init__(self):
		Renderer.__init__(self)
		self.nameCache = {}
		self.jpgname = ""
		
	def applySkin(self, desktop, parent):
		attribs = []
		for (attrib, value) in self.skinAttributes:
			if attrib == "path":
				self.path = value
			else:
				attribs.append((attrib, value))
			
		self.skinAttributes = attribs
		return Renderer.applySkin(self, desktop, parent)
		
	GUI_WIDGET = ePixmap
	
	def changed(self, what):
		if self.instance and config.merlin2.showcoverinmovielist.value:
			jpgname = ""
			if what[0] != self.CHANGED_CLEAR:
				moviename = self.source.text
				
				jpgname = self.nameCache.get(moviename, "")
				if jpgname == "":
					jpgname = self.findCover(moviename)
					if jpgname != "":
						self.nameCache[moviename] = jpgname
			if jpgname == "": # no cover for movie found
				jpgname = self.nameCache.get("default", "")
				if jpgname == "": # no default yet in cache..
					jpgname = self.findCover("cover_default")
					if jpgname == "":
						tmp = resolveFilename(SCOPE_CURRENT_SKIN, "cover_default.jpg")
						if fileExists(tmp):
							jpgname = tmp
						else:
							jpgname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/cover_default.jpg")
					self.nameCache["default"] = jpgname
			if self.jpgname != jpgname:
				self.instance.setPixmapFromFile(jpgname)
				self.jpgname = jpgname
				
	def findCover(self, moviename):
		for path in self.searchPaths:
			jpgname = (path) + moviename + ".jpg"
			print "jpgname", jpgname
			if fileExists(jpgname):
				return jpgname
		return ""
				
